@@ -2,7 +2,7 @@
 **  CWFolder.h
 **
 **  Copyright (c) 2001-2006 Ludovic Marcotte
-**  Copyright (C) 2013-2017 The GNUstep team
+**  Copyright (C) 2013-2022 Riccardo Mottola
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **          Riccardo Mottola
@@ -35,6 +35,7 @@
 
 @class CWFlags;
 @class CWMessage;
+@class CWCacheManager;
 
 /*!
   @const PantomimeFolderAppendCompleted
@@ -286,16 +287,14 @@ extern NSString* PantomimeFolderSearchFailed;
 */
 @interface CWFolder : NSObject 
 {
-  @public
-    NSMutableArray *allMessages;
-
   @protected
     NSMutableDictionary *_properties;
     NSString *_name;
 
-    id _cacheManager;
+    CWCacheManager *_cacheManager;
     id _store;
 
+    NSMutableArray *_allMessages;
     NSMutableArray *_allVisibleMessages;
     NSMutableArray *_allContainers;
    
@@ -364,16 +363,13 @@ extern NSString* PantomimeFolderSearchFailed;
                               flags: (CWFlags *) theFlags;
 
 /*!
-  @method allMessages
-  @discussion This method is used to obtain all visible messages
-              in the CWFolder instance. It hides messages marked
-	      as Deleted if -setShowDeleted: was invoked with
-	      NO as the parameter and the the same for messages
-	      marked as read (see -setShowRead:). Note that the
+  @method messages
+  @discussion This method is used to obtain all messages
+              in the CWFolder instance. Note that the
 	      messages MIGHT NOT been all completely initialized.
-  @result An array of all visible messages.
+  @result A mutable array of messages.
 */
-- (NSArray *) allMessages;
+- (NSMutableArray *) messages;
 
 /*!
   @method setMessages:
@@ -384,6 +380,19 @@ extern NSString* PantomimeFolderSearchFailed;
 */
 - (void) setMessages: (NSArray *) theMessages;
 
+/*!
+  @method visibileMessages
+  @discussion This method is used to obtain all visible messages
+              in the CWFolder instance. It hides messages marked
+	      as Deleted if -setShowDeleted: was invoked with
+	      NO as the parameter and the the same for messages
+	      marked as read (see -setShowRead:). Note that the
+	      messages MIGHT NOT been all completely initialized.
+  @result An array of all visible messages.
+*/
+- (NSArray *) visibleMessages;
+
+
 /*!
   @method messageAtIndex:
   @discussion This method is used to obtain the message at the
@@ -395,7 +404,7 @@ extern NSString* PantomimeFolderSearchFailed;
 - (CWMessage *) messageAtIndex: (NSUInteger) theIndex;
 
 /*!
-  @method count
+  @method countVisible
   @discussion This method is used to obtain the number of messages
               present in the folder. Hidden messages will NOT
 	      be part of the value returned. So, for example, if
@@ -405,7 +414,7 @@ extern NSString* PantomimeFolderSearchFailed;
 	      8 as the messages count.
   @result The number of messages in the folder.
 */
-- (NSUInteger) count;
+- (NSUInteger) countVisible;
 
 /*!
   @method close
@@ -573,7 +582,7 @@ extern NSString* PantomimeFolderSearchFailed;
 	      For a CWPOP3Folder, a CWPOP3CacheManager instance will be returned.
   @result The associated cache manager instance, nil otherwise.
 */
-- (id) cacheManager;
+- (CWCacheManager *) cacheManager;
 
 /*!
   @method setCacheManager:
