@@ -2,8 +2,10 @@
 **  CWIMAPCacheManager.h
 **
 **  Copyright (c) 2001-2007 Ludovic Marcotte
+**  Copyright (C) 2018      Riccardo Mottola
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
+**          Riccardo Mottola <rm@gnu.org>
 **
 **  This library is free software; you can redistribute it and/or
 **  modify it under the terms of the GNU Lesser General Public
@@ -43,7 +45,11 @@
     CWFolder *_folder;
 }
 
-- (void) initInRange: (NSRange) theRange;
+- (id) initWithPath: (NSString *) thePath  folder: (CWFolder *) theFolder;
+
+- (void) readAllMessages;
+
+- (void) readMessagesInRange: (NSRange) theRange;
 
 /*!
   @method messageWithUID:
