@@ -22,7 +22,8 @@
 #ifndef _Pantomime_H_CWService
 #define _Pantomime_H_CWService
 
-#include <Pantomime/CWConnection.h>
+#import <Pantomime/CWConnection.h>
+#import <Pantomime/CWConstants.h>
 
 #import <Foundation/NSArray.h>
 #import <Foundation/NSObject.h>
@@ -49,7 +50,7 @@
 static inline NSData *split_lines(NSMutableData *theMutableData)
 {
   char *bytes, *end;
-  int i, count;
+  NSUInteger i, count;
 
   end = bytes = (char *)[theMutableData mutableBytes];
   count = [theMutableData length];
